Crate frozen_collections_macros

Crate frozen_collections_macros 

Implementation crate for the frozen collections.

This crate is an implementation detail of the `frozen_collections` crate. This crate's API is therefore not stable and may change at any time. Please do not use this crate directly and instead use the public API provided by the `frozen_collections` crate.

Macros

fz_hash_map
fz_hash_set
fz_ordered_map
fz_ordered_set
fz_scalar_map
fz_scalar_set
fz_string_map
fz_string_set

Derive Macros

Scalar