Implementation crate for the frozen collections.
This crate is an implementation detail of the `frozen_collections` crate.
This crate's API is therefore not stable and may change at any time. Please do not
use this crate directly and instead use the public API provided by the
`frozen_collections` crate.
Macros
- fz_
hash_ map - fz_
hash_ set - fz_
ordered_ map - fz_
ordered_ set - fz_
scalar_ map - fz_
scalar_ set - fz_
string_ map - fz_
string_ set